package com.example.bytheway.ui.help;

import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.example.bytheway.R;
import com.example.bytheway.UrlObject.UrlObject;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import okhttp3.Call;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class AnswerAdapter extends RecyclerView.Adapter<AnswerAdapter.ViewHolder>{

    private List<Answer> answers=new ArrayList<>();

    static class ViewHolder extends RecyclerView.ViewHolder{
        ImageView userHead;
        TextView userName;
        TextView floor;
        TextView answerContent;

        public ViewHolder(@NonNull View itemView) {
            super(itemView);
            this.userHead=(ImageView)itemView.findViewById(R.id.answerUserhead);
            this.userName=(TextView)itemView.findViewById(R.id.answerUserName);
            this.floor=(TextView)itemView.findViewById(R.id.answerFloor);
            this.answerContent=(TextView)itemView.findViewById(R.id.answer_content);
        }
    }

    public AnswerAdapter(List<Answer> answers) {
        this.answers = answers;
    }

    @NonNull

    public ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view= LayoutInflater.from(parent.getContext()).inflate(R.layout.answer_list,parent,false);
        final ViewHolder holder=new ViewHolder(view);
        Log.d("answerAdapter","onCreateViewHolder");
        return holder;
    }

    @Override
    public void onBindViewHolder(@NonNull ViewHolder holder, int position) {
        Answer answer=answers.get(position);
        holder.userHead.setImageResource(answer.getAnswerManHead());
        holder.userName.setText(answer.getAnswerManName());
        String f=" "+String.valueOf(position+1)+"楼";
        holder.floor.setText(f);
        holder.answerContent.setText(answer.getAnswerContent());
    }


    @Override
    public int getItemCount() {
        return answers.size();
    }


    public static List<Answer> findAnswer(int postId){

        try {
            String path = UrlObject.url_path + "ClientAnswerInfoServlet?id=0";
            URL url = new URL(path);

            OkHttpClient client = new OkHttpClient();
            Request request = new Request.Builder()
                    .url(url)
                    .build();
            Call call = client.newCall(request);
            Response response = call.execute();

            String responseData = response.body().string();
            Gson gson = new Gson();
            List<Answer> answers = gson.fromJson(responseData, new TypeToken<List<Answer>>() {
            }.getType());

            Answer answerTemp;
            List<Answer> answerOfPost=new ArrayList<>();
            for (int i=0;i<answers.size();i++){
                answerTemp=answers.get(i);
                if(answerTemp.postId==postId)
                {
                    answerOfPost.add(answerTemp);
                }
            }
            return answerOfPost;



        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }


//        List<Answer> answerTest=new ArrayList<>();
//        List<Answer> answers=new ArrayList<>();
//        Answer answerTemp;
//        Answer answer1=new Answer(1,1,0,R.mipmap.defaulthead,"这次想不冲都不行啦.jpg","孙悦超");
//        answerTest.add(answer1);
//        Answer answer2=new Answer(1,2,0,R.drawable.head2,"寄","刘辉");
//        answerTest.add(answer2);
//        Answer answer3=new Answer(2,1,0,R.drawable.head2,"寄","刘辉");
//        answerTest.add(answer3);
//        Answer answer4=new Answer(1,3,0,R.mipmap.defaulthead,"我好了","孙悦超");
//        answerTest.add(answer4);
//        answer1=new Answer(1,1,0,R.mipmap.defaulthead,"谢谢","孙悦超");
//        answerTest.add(answer1);
//
//        for (int i=0;i<answerTest.size();i++){
//            answerTemp=answerTest.get(i);
//            if(answerTemp.postId==postId)
//            {
//                answers.add(answerTemp);
//            }
//        }
//        return answers;
}
