package com.example.bytheway.ui.home;

import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.example.bytheway.R;
import com.example.bytheway.UrlObject.UrlObject;
import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import okhttp3.Call;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;

public class HomeAdapter extends RecyclerView.Adapter<HomeAdapter.ViewHolder> {

    private List<Home> homes;
    detailsListener toDetails;

    //在碎片中接口回调 把点击的列表项数据传给订单详情活动
    public interface detailsListener {
        public void onDetailsClick(Home order);
    }
    public void setOnDetailsClickListener (detailsListener  XXListener) {
        this.toDetails = XXListener;
    }


    static class ViewHolder extends RecyclerView.ViewHolder {
        ImageView userHead;
        TextView userName;
        TextView orderFrom;
        TextView orderTo;
        TextView orderReward;
        ImageButton details;

        public ViewHolder(@NonNull View itemView) {
            super(itemView);
            this.userHead = (ImageView) itemView.findViewById(R.id.order_list_userHead);
            this.userName = (TextView) itemView.findViewById(R.id.order_list_userName);
            this.orderFrom = (TextView) itemView.findViewById(R.id.order_list_fromStation);
            this.orderTo = (TextView) itemView.findViewById(R.id.order_list_toStation);
            this.orderReward=(TextView)itemView.findViewById(R.id.order_list_reward);
            this.details=(ImageButton)itemView.findViewById(R.id.to_order_details);
        }
    }

    public HomeAdapter(List<Home> homes) {
        this.homes = homes;
    }

    @NonNull
    public HomeAdapter.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(parent.getContext()).inflate(R.layout.order_list, parent, false);
        final ViewHolder holder = new ViewHolder(view);
        Log.d("HomeAdapter", "onCreateViewHolder: ");
        holder.details.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                int position=holder.getAdapterPosition();
                Home order=homes.get(position);
                toDetails.onDetailsClick(order);
            }
        });

        return holder;
    }

    @Override
    public void onBindViewHolder(@NonNull ViewHolder holder, int position) {
        Home home = homes.get(position);
        holder.userHead.setImageResource(home.getUser_head());
        holder.userName.setText(home.getOrderTitle());
        holder.orderFrom.setText(home.getOrderFrom());
        holder.orderTo.setText(home.getOrderTo());
        holder.orderReward.setText(String.valueOf(home.getReward()));
        Log.d("HomeAdapter", "onBindViewHolder: " + position);
    }



    public int getItemCount() {
        return homes.size();
    }

    public static List<Home> findHome() {


        try {
            String path = UrlObject.url_path + "ClientOrderInfoServlet";
            URL url = new URL(path);

            OkHttpClient client = new OkHttpClient();
            Request request = new Request.Builder()
                    .url(url)
                    .build();
            Call call = client.newCall(request);
            Response response = call.execute();

            String responseData = response.body().string();
            Gson gson = new Gson();
            List<Home> homes = gson.fromJson(responseData, new TypeToken<List<Home>>() {
            }.getType());
            List<Home> reverse_order=new ArrayList<>();
            for (int i=homes.size();i>0;i--){
                reverse_order.add(homes.get(i-1));
            }


            return reverse_order;


        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    public static List<Home> findHome_test(){
        List<Home> homes = new ArrayList<>();
        Home home1 = new Home("帮拿快递~", "天马菜鸟驿站", "21栋507", R.drawable.head1);
        home1.setReward(100);
        home1.setNote("火速火速火速");
        homes.add(home1);
        Home home2 = new Home("帮拿快递~", "天马菜鸟驿站", "26栋301", R.drawable.head3);
        homes.add(home2);
        Home home3 = new Home("外卖", "食堂正门", "1栋101", R.drawable.head1);
        homes.add(home3);
        Home home4 = new Home("拿快递", "天马妈妈驿站", "3栋514", R.drawable.head3);
        homes.add(home4);
        Home home5 = new Home("几件快递", "28栋圆通快递", "1栋101", R.drawable.head1);
        homes.add(home5);
        Home home6 = new Home("拿快递", "天马妈妈驿站", "3栋514", R.drawable.head3);
        homes.add(home6);
        return homes;



    }


}


